==> ai_webform_guard-1.0.9.zip: ai_webform_guard/src/Form/AIWebformGuardSettingsForm.php <==
<?php

namespace Drupal\ai_webform_guard\Form;

use Drupal\ai\Enum\AiModelCapability;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure AI Webform Guard module.
 */
class AIWebformGuardSettingsForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * Config settings.
   */
  const CONFIG_NAME = 'ai_webform_guard.settings';

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * AI Provider service.
   *
   * @var \Drupal\ai\AiProviderPluginManager
   */
  protected $providerManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    $instance->providerManager = $container->get('ai.provider');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ai_webform_guard_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::CONFIG_NAME,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Load config.
    $config = $this->config(static::CONFIG_NAME);

    $form['prompt'] = [
      '#title' => $this->t('Webform guard generation prompt'),
      '#type' => 'textarea',
      '#default_value' => $config->get('prompt') ?? '',
      '#description' => $this->t('Prompt used for generating the spam detection.'),
      '#required' => TRUE,
    ];
    $form['longer_description'] = [
      '#theme' => 'item_list',
      '#items' => [
        $this->t('Prompt is rendered using Twig rendering engine and supports the following tokens:'),
        '{{ entity_lang_name }} - ' . $this->t('Human readable name of the entity language'),
      ],
    ];

    $models = $this->providerManager->getSimpleProviderModelOptions('chat', TRUE, TRUE, [
      AiModelCapability::ChatJsonOutput,
    ]);

    $form['ai_model'] = [
      '#title' => $this->t('AI provider/model'),
      '#type' => 'select',
      '#options' => $models,
      '#default_value' => $config->get('ai_model') ?? '',
      '#empty_option' => $this->t('Use Default Webform Spam Vision Model'),
      '#description' => $this->t('AI model to use for spam detection.'),
    ];

    $form['error_message'] = [
      '#title' => $this->t('Custom error message for spam submissions'),
      '#type' => 'textfield',
      '#default_value' => $config->get('error_message') ?? '',
      '#description' => $this->t('This message will be shown if the submission is classified as spam. Leave empty to use the default message.'),
    ];

    $form['log_spam_attempts'] = [
      '#title' => $this->t('Log spam attempts'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('log_spam_attempts') ?? TRUE,
      '#description' => $this->t('Check to log blocked spam submissions to the watchdog log.'),
    ];

    $form['human_iteration'] = [
      '#title' => $this->t('Human iteration'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('human_iteration') ?? TRUE,
      '#description' => $this->t('Confirmation checkbox requiring human validation before allowing submission if flagged as spam.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::CONFIG_NAME)
      ->set('prompt', $form_state->getValue('prompt'))
      ->set('ai_model', $form_state->getValue('ai_model'))
      ->set('error_message', $form_state->getValue('error_message'))
      ->set('log_spam_attempts', $form_state->getValue('log_spam_attempts'))
      ->set('human_iteration', $form_state->getValue('human_iteration'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}

==> ai_webform_guard-1.1.0.zip: ai_webform_guard/src/Form/AIWebformGuardSettingsForm.php <==
<?php

namespace Drupal\ai_webform_guard\Form;

use Drupal\ai\Enum\AiModelCapability;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure AI Webform Guard module.
 */
class AIWebformGuardSettingsForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * Config settings.
   */
  const CONFIG_NAME = 'ai_webform_guard.settings';

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * AI Provider service.
   *
   * @var \Drupal\ai\AiProviderPluginManager
   */
  protected $providerManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    $instance->providerManager = $container->get('ai.provider');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ai_webform_guard_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::CONFIG_NAME,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Load config.
    $config = $this->config(static::CONFIG_NAME);

    $form['prompt'] = [
      '#title' => $this->t('Webform guard generation prompt'),
      '#type' => 'textarea',
      '#default_value' => $config->get('prompt') ?? '',
      '#description' => $this->t('Prompt used for generating the spam detection.'),
      '#required' => TRUE,
    ];
    $form['longer_description'] = [
      '#theme' => 'item_list',
      '#items' => [
        $this->t('Prompt is rendered using Twig rendering engine and supports the following tokens:'),
        '{{ entity_lang_name }} - ' . $this->t('Human readable name of the entity language'),
      ],
    ];

    $models = $this->providerManager->getSimpleProviderModelOptions('chat', TRUE, TRUE, [
      AiModelCapability::ChatJsonOutput,
    ]);

    $form['ai_model'] = [
      '#title' => $this->t('AI provider/model'),
      '#type' => 'select',
      '#options' => $models,
      '#default_value' => $config->get('ai_model') ?? '',
      '#empty_option' => $this->t('Use Default Webform Spam Vision Model'),
      '#description' => $this->t('AI model to use for spam detection.'),
    ];

    $form['error_message'] = [
      '#title' => $this->t('Custom error message for spam submissions'),
      '#type' => 'textfield',
      '#default_value' => $config->get('error_message') ?? '',
      '#description' => $this->t('This message will be shown if the submission is classified as spam. Leave empty to use the default message.'),
    ];

    $form['log_spam_attempts'] = [
      '#title' => $this->t('Log spam attempts'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('log_spam_attempts') ?? TRUE,
      '#description' => $this->t('Check to log blocked spam submissions to the watchdog log.'),
    ];

    $form['human_iteration'] = [
      '#title' => $this->t('Human iteration'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('human_iteration') ?? FALSE,
      '#description' => $this->t('Confirmation checkbox requiring human validation before allowing submission if flagged as spam.'),
    ];

    $form['max_words'] = [
      '#title' => $this->t('Maximum number of words per AI request'),
      '#type' => 'number',
      '#default_value' => $config->get('max_words') ?? 500,
      '#min' => 30,
      '#description' => $this->t('Limits the number of words sent to the AI for analysis to reduce resource usage.
    On average, one word equals about 1.3–1.5 tokens. For example, 500 words ≈ 650–750 tokens.
    The fewer words you send, the fewer tokens (and energy/resources) are used.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::CONFIG_NAME)
      ->set('prompt', $form_state->getValue('prompt'))
      ->set('ai_model', $form_state->getValue('ai_model'))
      ->set('error_message', $form_state->getValue('error_message'))
      ->set('log_spam_attempts', $form_state->getValue('log_spam_attempts'))
      ->set('human_iteration', $form_state->getValue('human_iteration'))
      ->set('max_words', $form_state->getValue('max_words'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
